# MONK Framework

A framework for abstracting DFE embedded systems to simplify Unit- and
Integrationtests.

For details, have a look at [our Wiki](https://github.com/DFE/MONK/wiki).
Changes will be tested and built in [Travis-CI](https://travis-ci.org/DFE/MONK).
